@@ -18,7 +18,7 @@
 #include <stdio.h>
 #include <qplatformdefs.h>
 #include <signal.h>
-#include <errno.h>
+#include <cerrno>
 
 #if HAVE_X11
 #include <kstartupinfo.h>
@@ -30,7 +30,6 @@
 #endif
 
 #include <QDBusConnectionInterface>
-#include <QDBusMessage>
 #include <QFile>
 #include <QFileInfo>
 #include <QUrl>
@@ -497,11 +496,7 @@ KLauncher::requestStart(KLaunchRequest *request)
     if (!process->waitForStarted()) {
         processRequestReturn(LAUNCHER_ERROR, "");
     } else {
-#ifndef Q_OS_WIN
-        request->pid = process->pid();
-#else
-        request->pid = process->pid()->dwProcessId;
-#endif
+        request->pid = process->processId();
         QByteArray data((char *)&request->pid, sizeof(int));
         processRequestReturn(LAUNCHER_OK, data);
     }
@@ -987,7 +982,7 @@ KLauncher::requestSlave(const QString &protocol,
 #ifdef Q_OS_WIN
     QString name = QLatin1String("kioslave");
 #else
-    QString name = QFile::decodeName(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/kioslave");
+    QString name = QFile::decodeName(KDE_INSTALL_FULL_LIBEXECDIR_KF5 "/kioslave");
 #endif
 #else
     QString arg1 = protocol;
@@ -1017,7 +1012,7 @@ KLauncher::requestSlave(const QString &protocol,
 #ifdef Q_OS_WIN
         arg_list.prepend(QLatin1String("kioslave"));
 #else
-        arg_list.prepend(QFile::decodeName(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/kioslave"));
+        arg_list.prepend(QFile::decodeName(KDE_INSTALL_FULL_LIBEXECDIR_KF5 "/kioslave"));
 #endif
 #endif
         name = QStringLiteral("valgrind");
